@@ -120,14 +120,14 @@ public:
         notifyWatchersPaletteChange();
     }
 
-    Colors loadColors(Kirigami::PlatformTheme::ColorSet cs, QPalette::ColorGroup group)
+    Colors loadColors(Kirigami::Platform::PlatformTheme::ColorSet cs, QPalette::ColorGroup group)
     {
         const auto key = qMakePair(cs, group);
         auto it = m_cache.constFind(key);
         if (it != m_cache.constEnd())
             return *it;
 
-        using Kirigami::PlatformTheme;
+        using Kirigami::Platform::PlatformTheme;
 
         KColorScheme::ColorSet set;
 
@@ -197,7 +197,7 @@ public:
 
     void notifyWatchersPaletteChange()
     {
-        for (auto watcher : qAsConst(watchers)) {
+        for (auto watcher : std::as_const(watchers)) {
             watcher->syncColors();
         }
     }
@@ -205,7 +205,7 @@ public:
     Q_SLOT void notifyWatchersConfigurationChange()
     {
         smallFont = loadSmallFont();
-        for (auto watcher : qAsConst(watchers)) {
+        for (auto watcher : std::as_const(watchers)) {
             watcher->setSmallFont(smallFont);
             watcher->setDefaultFont(qApp->font());
         }
@@ -214,19 +214,16 @@ public:
     KColorScheme buttonScheme;
     QFont smallFont;
 
-    QVector<PlasmaDesktopTheme *> watchers;
+    QList<PlasmaDesktopTheme *> watchers;
 
 private:
-    QHash<QPair<Kirigami::PlatformTheme::ColorSet, QPalette::ColorGroup>, Colors> m_cache;
+    QHash<QPair<Kirigami::Platform::PlatformTheme::ColorSet, QPalette::ColorGroup>, Colors> m_cache;
 };
 Q_GLOBAL_STATIC(StyleSingleton, s_style)
 
 PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
     : PlatformTheme(parent)
 {
-    // TODO: MOVE THIS SOMEWHERE ELSE
-    m_lowPowerHardware = QByteArrayList{"1", "true"}.contains(qgetenv("KIRIGAMI_LOWPOWER_HARDWARE").toLower());
-
     // We don't use KIconLoader on Android so we don't support recoloring there
 #ifndef Q_OS_ANDROID
     setSupportsIconColoring(true);
@@ -352,64 +349,25 @@ void PlasmaDesktopTheme::syncColors()
     // decoration
     setHoverColor(colors.scheme.decoration(KColorScheme::HoverColor).color());
     setFocusColor(colors.scheme.decoration(KColorScheme::FocusColor).color());
-
-    // Breeze QQC2 style colors
-    const QColor &buttonTextColor = s_style->buttonScheme.foreground(KColorScheme::NormalText).color();
-    const QColor &buttonBackgroundColor = s_style->buttonScheme.background(KColorScheme::NormalBackground).color();
-    auto separatorColor = [](const QColor &bg, const QColor &fg, const qreal baseRatio = 0.2) {
-        return KColorUtils::luma(bg) > 0.5 ? KColorUtils::mix(bg, fg, baseRatio) : KColorUtils::mix(bg, fg, baseRatio / 2);
-    };
-
-    m_buttonSeparatorColor = separatorColor(buttonBackgroundColor, buttonTextColor, 0.3);
-
-    switch (colorSet()) {
-        // case ColorSet::View:
-        // case ColorSet::Window:
-    case ColorSet::Button:
-        m_separatorColor = m_buttonSeparatorColor;
-        break;
-    case ColorSet::Selection:
-        m_separatorColor = focusColor();
-        break;
-        // case ColorSet::Tooltip:
-        // case ColorSet::Complementary:
-        // case ColorSet::Header:
-    default:
-        m_separatorColor = separatorColor(backgroundColor(), textColor());
-    }
 }
 
 bool PlasmaDesktopTheme::event(QEvent *event)
 {
-    if (event->type() == Kirigami::PlatformThemeEvents::DataChangedEvent::type) {
+    if (event->type() == Kirigami::Platform::PlatformThemeEvents::DataChangedEvent::type) {
         syncColors();
     }
 
-    if (event->type() == Kirigami::PlatformThemeEvents::ColorSetChangedEvent::type) {
+    if (event->type() == Kirigami::Platform::PlatformThemeEvents::ColorSetChangedEvent::type) {
         syncColors();
     }
 
-    if (event->type() == Kirigami::PlatformThemeEvents::ColorGroupChangedEvent::type) {
+    if (event->type() == Kirigami::Platform::PlatformThemeEvents::ColorGroupChangedEvent::type) {
         syncColors();
     }
 
     return PlatformTheme::event(event);
 }
 
-// Breeze QQC2 style colors
-QColor PlasmaDesktopTheme::separatorColor() const
-{
-    return m_separatorColor;
-}
-
-QColor PlasmaDesktopTheme::buttonSeparatorColor() const
-{
-    return m_buttonSeparatorColor;
-}
-
-bool PlasmaDesktopTheme::lowPowerHardware() const
-{
-    return m_lowPowerHardware;
-}
-
 #include "plasmadesktoptheme.moc"
+
+#include "moc_plasmadesktoptheme.cpp"
